import React, { createRef, forwardRef, useImperativeHandle } from 'react';
import { KeyboardAvoidingView, Modal as RNModal, TouchableOpacity, View, } from 'react-native';
import { GestureHandlerRootView, PanGestureHandler, ScrollView, } from 'react-native-gesture-handler';
import Animated from 'react-native-reanimated';
import { Constants } from '../../constants';
import { globalMetrics } from '../../theme';
import { useSwippableModal } from './hooks';
import styles from './styles/SwippableModalStyles';
export const modalRef = createRef();
/**
 * functions are used for show and hide modal directly
 */
export const showModal = () => { var _a; return (_a = modalRef === null || modalRef === void 0 ? void 0 : modalRef.current) === null || _a === void 0 ? void 0 : _a.show(); };
export const hideModal = () => { var _a; return (_a = modalRef === null || modalRef === void 0 ? void 0 : modalRef.current) === null || _a === void 0 ? void 0 : _a.hide(); };
const { isAndroid } = globalMetrics;
export const panRef = createRef();
const SwippableModal = forwardRef(({ children, modalStyle, modalBackgroundColor, disableLine, modalInnerContainerStyle, disableClose, disableBackgroundColor, disableSwipeDown = false, closeThreadSoldValue = Constants.MODAL_CLOSE_THRESHOLD, panGestureProps, modalContainerStyle, modalLineStyle, ...rest }, ref) => {
    const { translateY, setVisible, visible, panEnabled, scrollRef, eventHandler, modalDownStyles, setPanEnabled, } = useSwippableModal(closeThreadSoldValue, disableSwipeDown);
    /**
     * reference use for opening modal
     */
    useImperativeHandle(ref !== null && ref !== void 0 ? ref : modalRef, () => ({
        show: () => {
            setVisible(true);
            translateY.value = 0;
            return Promise.resolve();
        },
        hide: () => {
            setVisible(false);
            translateY.value = 0;
            return Promise.resolve();
        },
    }));
    const keyBoardBehavior = !isAndroid ? 'padding' : undefined;
    return (React.createElement(RNModal, { visible: visible, animationType: 'fade', transparent: true, onRequestClose: () => setVisible(false), ...rest },
        React.createElement(View, { style: [
                styles.inputContainer,
                modalStyle,
                disableBackgroundColor && styles.inputContainerBackgroundColor,
            ] },
            React.createElement(TouchableOpacity, { style: styles.touchableOpacityStyle, onPressOut: () => !disableClose && setVisible(false) }),
            React.createElement(KeyboardAvoidingView, { behavior: keyBoardBehavior },
                React.createElement(GestureHandlerRootView, null,
                    React.createElement(PanGestureHandler, { enabled: panEnabled, ref: panRef, simultaneousHandlers: scrollRef, onGestureEvent: eventHandler, ...{ panGestureProps } },
                        React.createElement(Animated.View, { style: [
                                styles.keyboardAvoidingStyle,
                                modalBackgroundColor,
                                modalDownStyles,
                            ] },
                            React.createElement(ScrollView, { ref: scrollRef, simultaneousHandlers: panRef, contentContainerStyle: styles.scrollViewStyle, nestedScrollEnabled: true, keyboardShouldPersistTaps: "handled", showsVerticalScrollIndicator: false, onScrollEndDrag: event => !disableSwipeDown &&
                                    setPanEnabled(event.nativeEvent.contentOffset.y <= 0), scrollEventThrottle: 16 },
                                React.createElement(View, null,
                                    React.createElement(View, { style: [styles.bodyContainer, modalContainerStyle] },
                                        !disableLine && (React.createElement(View, { style: [styles.modalLineStyle, modalLineStyle] })),
                                        React.createElement(View, { style: [
                                                styles.bodyContainerHeader,
                                                disableLine && styles.bodyContainerHeaderDisable,
                                                modalInnerContainerStyle,
                                            ] }, children)))))))))));
});
export default SwippableModal;
//# sourceMappingURL=SwippableModal.js.map